<TS language="th" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>สร้างที่อยู่ใหม่</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;ใหม่</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>คัดลอกที่อยู่ที่เลือกในปัจจุบันไปยังคลิปบอร์ดของระบบ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;คัดลอก</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;ปิด</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>ลบที่อยู่ที่เลือกในปัจจุบันออกจากรายการ</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>ป้อนที่อยู่หรือป้ายชื่อเพื่อค้นหา</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ส่งออกข้อมูลในแท็บปัจจุบันไปยังไฟล์</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ส่งออก</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ลบ</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>เลือกที่อยู่ที่จะส่งเหรียญ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>เลือกที่อยู่ที่จะรับเหรียญ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;เลือก</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>ที่อยู่การส่ง</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>ที่อยู่การรับ</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>ที่อยู่ Bitcoin ของคุณสำหรับการส่งการชำระเงิน โปรดตรวจสอบจำนวนเงินและที่อยู่รับก่อนที่จะส่งเหรียญ</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;คัดลอกที่อยู่</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>&amp;คัดลอกป้ายชื่อ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;แก้ไข</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>ส่งออกรายการที่อยู่</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ไฟล์ที่คั่นด้วยจุลภาค (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>การส่งออกล้มเหลว</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>เกิดข้อผิดพลาดขณะพยายามบันทึกรายการที่อยู่ไปยัง %1 โปรดลองอีกครั้ง</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ป้ายชื่อ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>ที่อยู่</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีป้ายชื่อ)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>กล่องโต้ตอบวลีรหัสผ่าน</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>ป้อนวลีรหัสผ่าน</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>วลีรหัสผ่านใหม่</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>ทำซ้ำวลีรหัสผ่านใหม่</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>แสดงวลีรหัสผ่าน</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>เข้ารหัสกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>การดำเนินการนี้ต้องการวลีรหัสผ่านกระเป๋าสตางค์ของคุณเพื่อปลดล็อคกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>ปลดล็อคกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>การดำเนินการนี้ต้องการวลีรหัสผ่านกระเป๋าสตางค์ของคุณเพื่อถอดรหัสกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>ถอดรหัสกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>เปลี่ยนวลีรหัสผ่าน</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>ยืนยันการเข้ารหัสกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>คุณแน่ใจหรือไม่ว่าต้องการเข้ารหัสกระเป๋าสตางค์ของคุณ?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>เข้ารหัสบัญชีเรียบร้อย</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>บัญชีของคุณกำลังถูกเข้ารหัส</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>บัญชีของคุณถูกเข้ารหัสเรียบร้อยแล้ว</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>การเข้ารหัสกระเป๋าสตางค์ล้มเหลว</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>การปลดล็อคกระเป๋าสตางค์ล้มเหลว</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>การถอดรหัสกระเป๋าสตางค์ล้มเหลว</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask (ตัวกรอง IP)</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>ห้ามจนถึง</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;เซ็นข้อความ...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>กำลังทำข้อมูลให้ตรงกันกับเครือข่าย ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;ภาพรวม</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>แสดงภาพรวมทั่วไปของกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;ธุรกรรม</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>เรียกดูประวัติการทำธุรกรรม</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;ออก</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>ออกจากแอปพลิเคชัน</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;เกี่ยวกับ %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>แสดงข้อมูลเกี่ยวกับ %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>เกี่ยวกับ &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>แสดงข้อมูลเกี่ยวกับ Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;ตัวเลือก...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>ปรับเปลี่ยนตัวเลือกการกำหนดค่าสำหรับ %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;เข้ารหัสกระเป๋าสตางค์...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;สำรองข้อมูลกระเป๋าสตางค์...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;เปลี่ยนวลีรหัสผ่าน...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>&amp;เปิด URI...</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>สร้างกระเป๋าสตางค์...</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>สร้างกระเป๋าสตางค์ใหม่</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>กระเป๋าสตางค์:</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>กำลังซิงค์ส่วนหัว (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>กำลังทำดัชนี ที่เก็บบล็อก ใหม่ ในดิสก์...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>ส่งเหรียญไปยังที่อยู่ Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>สำรองข้อมูลกระเป๋าสตางค์ไปยังตำแหน่งที่ตั้งอื่น</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>เปลี่ยนรหัสผ่านที่ใช้สำหรับการเข้ารหัสกระเป๋าเงิน</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;ยืนยันข้อความ...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;ส่ง</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;รับ</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;แสดง / ซ่อน</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>แสดงหรือซ่อนหน้าต่างหลัก</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>เข้ารหัสกุญแจส่วนตัวที่เป็นของกระเป๋าสตางค์ของคุณ</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>เซ็นชื่อด้วยข้อความ ที่เก็บ Bitcoin เพื่อแสดงว่าท่านเป็นเจ้าของ bitcoin นี้จริง</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>ตรวจสอบ ข้อความ เพื่อให้แน่ใจว่า การเซ็นต์ชื่อ ด้วยที่เก็บ Bitcoin แล้ว</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;ไฟล์</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;การตั้งค่า</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;ช่วยเหลือ</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>แถบเครื่องมือแท็บ</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>เรียกเก็บ การชำระเงิน (สร้าง QR codes และ bitcoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>แสดงรายการ ที่เก็บเงินที่จะส่ง bitcoin ออก และป้ายชื่อ ที่ใช้ไปแล้ว</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>แสดงรายการ ที่เก็บเงินที่จะรับ bitcoin เข้า และป้ายชื่อ ที่ใช้ไปแล้ว</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;ตัวเลือก Command-line</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>การกำลังสร้างดัชนีของบล็อก ในดิสก์...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>กำลังดำเนินการกับบล็อกในดิสก์...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>%n บล็อกในประวัติรายการ ได้รับการดำเนินการเรียบร้อยแล้ว</numerusform></translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 ตามหลัง</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>บล็อกสุดท้ายที่ได้รับ สร้างขึ้นเมื่อ %1 มาแล้ว</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>ธุรกรรมหลังจากนี้จะยังไม่สามารถมองเห็น</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ข้อผิดพลาด</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>คำเตือน</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>ข้อมูล</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>ทันสมัย</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file...</source>
        <translation>&amp;โหลด PSBT จากไฟล์...</translation>
    </message>
    <message>
        <source>Load PSBT from clipboard...</source>
        <translation>โหลด PSBT จากคลิปบอร์ด...</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>หน้าต่างโหนด</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>เปิด แผลงควบคุม debugging และ diagnostic</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation>&amp;ที่อยู่การส่ง</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation>&amp;ที่อยู่การรับ</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>เปิดกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>เปิดกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>ปิดกระเป๋าสตางค์...</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>ปิดกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Close All Wallets...</source>
        <translation>ปิดกระเป๋าสตางค์ทั้งหมด...</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>ปิดกระเป๋าสตางค์ทั้งหมด</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation>แสดง %1 ข้อความช่วยเหลือ เพื่อแสดงรายการ ตัวเลือกที่เป็นไปได้สำหรับ Bitcoin command-line</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation>ไม่มีกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;หน้าต่าง</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>ย่อ</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>ซูม</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation>หน้าต่างหลัก</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 ลูกค้า</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished"><numerusform>%n ช่องการเชื่อมต่อที่ใช้งานได้ เพื่อเชื่อมกับเครือข่าย Bitcoin</numerusform><numerusform>%n ช่องการเชื่อมต่อที่ใช้งานได้ เพื่อเชื่อมกับเครือข่าย Bitcoin</numerusform></translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>กำลังตามให้ทัน...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>ข้อผิดพลาด: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>คำเตือน: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>วันที่: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>จำนวน: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>กระเป๋าสตางค์: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>ชนิด: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>ป้ายชื่อ: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>ที่อยู่: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>รายการที่ส่ง</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>การทำรายการขาเข้า</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>ระเป๋าเงินถูก &lt;b&gt;เข้ารหัส&lt;/b&gt; และในขณะนี้ &lt;b&gt;ปลดล็อคแล้ว&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>กระเป๋าเงินถูก &lt;b&gt;เข้ารหัส&lt;/b&gt; และในปัจจุบัน &lt;b&gt;ล็อค &lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation>ข้อความดั้งเดิม:</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation>เกิดข้อผิดพลาดร้ายแรง %1 ไม่สามารถดำเนินการต่อได้อย่างปลอดภัยอีกต่อไปและจะยกเลิก</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>การเลือกเหรียญ</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>ปริมาณ:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ไบต์:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>เศษ:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>ส่วนที่เหลือจากค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>เงินทอน:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(ไม่)เลือกทั้งหมด</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>โหมดแบบต้นไม้</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>โหมดแบบรายการ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>จำนวน</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>รับด้วยป้ายชื่อ</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>รับด้วยที่อยู่</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>วันที่</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>การยืนยัน</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>ยืนยันแล้ว</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>คัดลอกจำนวนเงิน</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;คัดลอกที่อยู่</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;คัดลอกป้ายกำกับ</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;คัดลอกจำนวนเงิน</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;คัดลอก ID ธุรกรรม</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;Lock unspent</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีป้ายชื่อ)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>เปลี่ยนจาก %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(เปลี่ยน)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation>สร้างกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation>กำลังสร้างกระเป๋าสตางค์ &lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation>สร้างกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>กระเป๋าเงิน</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation>ชื่อกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>เข้ารหัสกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation>ปิดใช้งานกุญแจส่วนตัว</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation>สร้างกระเป๋าสตางค์เปล่า</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>สร้าง</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>แก้ไขที่อยู่</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;ป้ายชื่อ</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>รายการแสดง ป้ายชื่อที่เกี่ยวข้องกับที่เก็บนี้</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>ที่เก็บที่เกี่ยวข้องกับ ที่เก็บที่แสดงรายการนี้ การปรับปรุงนี้ทำได้สำหรับ ที่เก็บเงินที่จะใช่ส่งเงิน เท่านั้น</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;ที่อยู่</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>ที่อยู่การส่งใหม่</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>แก้ไขที่อยู่การรับ</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>แก้ไขที่อยู่การส่ง</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>ไม่สามารถปลดล็อคกระเป๋าสตางค์</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>ไดเร็กทอรี่ใหม่ที่ใช้เก็บข้อมูลจะถูกสร้างขึ้นมา</translation>
    </message>
    <message>
        <source>name</source>
        <translation>ชื่อ</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>มีไดเรกทอรีอยู่แล้ว เพิ่ม %1 หากคุณต้องการสร้างไดเรกทอรีใหม่ที่นี่</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>มีเส้นทางอยู่แล้วและไม่ใช่ไดเรกทอรี</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>ไม่สามารถสร้างไดเรกทอรีข้อมูลที่นี่</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>รุ่น</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>เกี่ยวกับ %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>ตัวเลือกบรรทัดคำสั่ง</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>ยินดีต้อนรับ</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>ยินดีต้อนรับสู่ %1</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation>นี่เป็นการรันโปรแกรมครั้งแรก ท่านสามารถเลือก ว่าจะเก็บข้อมูลไว้ที่ %1</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>ใช้ไดเรกทอรีข้อมูลเริ่มต้น</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>ใช้ไดเรกทอรีข้อมูลที่กำหนดเอง:</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation>ประมาณ %1 GB ของข้อมูลจะเก็บในไดเร็กทอรี่</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <comment>block chain pruning</comment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>The wallet เก็บใว้ในไดเร็กทอรี่</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation>ข้อผิดพลาด: ไดเร็กทอรี่ข้อมูลที่ต้องการ "%1" ไม่สามารถสร้างได้</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ข้อผิดพลาด</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation><numerusform>%n GB พื้นที่ว่างบนดิสก์ที่ใช้ได้</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation><numerusform>(ต้องการพื้นที่ %n GB)</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation><numerusform>(%n GB needed for full chain)</numerusform></translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>รูป</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>ความคืบหน้า</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>กำลังคำนวณ...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>ซ่อน</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>ชนิด</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>ที่อยู่</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>วางที่อยู่จากคลิปบอร์ด</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation>กระเป๋าสตางค์เริ่มต้น</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation>เปิดกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation>กำลังเปิดกระเป๋าสตางค์ &lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>ตัวเลือก</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;หลัก</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation>เริ่มต้นอัตโนมัติ %1 หลังจาก ล็อกอิน เข้าสู่ระบบแล้ว</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation>&amp;เริ่ม %1 ในการล็อกอินระบบ</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>ขนาดของ &amp;database cache</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>จำนวนของสคริปท์ &amp;verification threads</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>IP แอดเดส ของ proxy (เช่น IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>&amp;Hide tray icon</source>
        <translation>&amp;ซ่อนไอคอนถาด</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation>มินิไมซ์แอพ แทนการออกจากแอพพลิเคชั่น เมื่อวินโดว์ได้รับการปิด เมื่อเลือกตัวเลือกนี้ แอพพลิเคชั่น จะถูกปิด ก็ต่อเมื่อ มีการเลือกเมนู Exit/ออกจากระบบ เท่านั้น</translation>
    </message>
    <message>
        <source>Third party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation>URL แบบอื่น (ยกตัวอย่าง เอ็กพลอเลอร์บล็อก) ที่อยู่ใน เมนูรายการ ลำดับ %s ใน URL จะถูกเปลี่ยนด้วย รายการแฮช URL ที่เป็นแบบหลายๆอัน จะถูกแยก โดย เครื่องหมายเส้นบาร์ตั้ง |</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>เปิดไฟล์การกำหนดค่า</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>รีเซต ไคลเอ็นออพชั่น กลับไปเป็นค่าเริ่มต้น</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;รีเซต ออพชั่น</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;เครือข่าย</translation>
    </message>
    <message>
        <source>(0 = auto, &lt;0 = leave that many cores free)</source>
        <translation>(0 = อัตโนมัติ, &lt;0 = ปล่อย คอร์ อิสระ)</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>&amp;กระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>ผู้เชี่ยวชาญ</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation>เปิดใช้ coin &amp; รูปแบบการควบคุม</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation>หากท่านไม่เปิดใช้ การใช้เงินทอนที่ยังไม่ยืนยัน เงินทอนจากการทำรายการจะไม่สามารถใช้ได้ จนกว่ารายการที่ทำการ จะได้รับการยืนยันหนึ่งครั้ง และจะกระทบการคำนวณยอดคงเหลือของท่านด้วย</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation>&amp;ใช้เงินทอนที่ยังไม่ยืนยัน</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>เปิด Bitcoin ไคล์เอ็นท์พอร์ต/client port บน router โดยอัตโนมัติ วิธีนี้ใช้ได้เมื่อ router สนับสนุน UPnP และสถานะเปิดใช้งาน</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>จองพอร์ต โดยใช้ &amp;UPnP</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
        <translation>เชื่อมต่อกับ Bitcoin เน็ตเวิร์ก ผ่านพร็อกซี่แบบ SOCKS5</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation>&amp;เชื่อมต่อผ่าน พร็อกซี่ SOCKS5 (พร็อกซี่เริ่มต้น):</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>พร็อกซี่ &amp;IP:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;พอร์ต</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>พอร์ตของพร็อกซี่ (ตัวอย่าง 9050)</translation>
    </message>
    <message>
        <source>Used for reaching peers via:</source>
        <translation>ใช้ในการเข้าถึงอีกฝ่ายหนึ่ง peer โดย:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;หน้าต่าง</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>แสดงเฉพาะไอคอนถาดหลังจากย่อหน้าต่าง</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;ภาษาส่วนติดต่อผู้ใช้:</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a separate SOCKS5 proxy for Tor onion services.</source>
        <translation>เชื่อมต่อกับ เครือข่าย Bitcoin ผ่านทาง พร้อกซี่ SOCKS5 แยกต่างหาก สำหรับ Tor เซอร์วิส</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;ตกลง</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ยกเลิก</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>ตัวเลือกการกำหนดค่า</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ข้อผิดพลาด</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>รูป</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>ยอดดุล</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Copy to Clipboard</source>
        <translation>คัดลอกไปยังคลิปบอร์ด</translation>
    </message>
    <message>
        <source>Save...</source>
        <translation>บันทึก...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>ปิด</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Type</source>
        <translation>ชนิด</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>จำนวน</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n วินาที</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n นาที</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation><numerusform>%n ชั่วโมง</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation><numerusform>%n วัน</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n สัปดาห์</numerusform></translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 และ %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation><numerusform>%n ปี</numerusform></translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>ข้อผิดพลาด: %1</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>Save QR Code</source>
        <translation>บันทึกรหัส QR</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;ข้อมูล</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">เน็ตเวิร์ก</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation>กระเป๋าสตางค์: </translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>หน้าต่างโหนด</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;เปิด</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;คอนโซล</translation>
    </message>
    <message>
        <source>To</source>
        <translation>ถึง</translation>
    </message>
    <message>
        <source>From</source>
        <translation>จาก</translation>
    </message>
    <message>
        <source>1 d&amp;ay</source>
        <translation type="unfinished">1 &amp;day</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;คัดลอกที่อยู่</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;จำนวน:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;ป้ายชื่อ:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;ข้อความ:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>ล้าง</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>แสดง</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>เอาออก</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>&amp;คัดลอก URI</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;คัดลอกที่อยู่</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;คัดลอกป้ายชื่อ</translation>
    </message>
    <message>
        <source>Copy &amp;message</source>
        <translation type="unfinished">&amp;คัดลอกข้อความ</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;คัดลอกจำนวนเงิน</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>ไม่สามารถปลดล็อคกระเป๋าสตางค์</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation>ที่อยู่:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>ป้ายชื่อ:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>ข้อความ:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>กระเป๋าสตางค์:</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>&amp;คัดลอก URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;คัดลอกที่อยู่</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>วันที่</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ป้ายชื่อ</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>ข้อความ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีป้ายชื่อ)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>ส่งเหรียญ</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ไบต์:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>ส่วนที่เหลือจากค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>เงินทอน:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>เลือก...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>ซ่อน</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>แนะนำ:</translation>
    </message>
    <message>
        <source>Custom:</source>
        <translation>กำหนดเอง:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>เศษ:</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;ส่ง</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>คัดลอกจำนวนเงิน</translation>
    </message>
    <message>
        <source> from wallet '%1'</source>
        <translation>จากกระเป๋าสตางค์ '%1'</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>ส่ง</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation><numerusform>Estimated to begin confirmation within %n blocks.</numerusform></translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีป้ายชื่อ)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;จำนวน:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;ป้ายชื่อ:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>วางที่อยู่จากคลิปบอร์ด</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>ข้อความ:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation type="unfinished">&amp;เซ็นข้อความ</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>วางที่อยู่จากคลิปบอร์ด</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>ลายเซ็น</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>&amp;เซ็นข้อความ</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;ยืนยันข้อความ</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">&amp;ยืนยันข้อความ</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>ไม่มีข้อผิดพลาด</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation><numerusform>Open for %n more blocks</numerusform></translation>
    </message>
    <message>
        <source>Status</source>
        <translation>สถานะ</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>วันที่</translation>
    </message>
    <message>
        <source>From</source>
        <translation>จาก</translation>
    </message>
    <message>
        <source>To</source>
        <translation>ถึง</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation><numerusform>matures in %n more blocks</numerusform></translation>
    </message>
    <message>
        <source>Message</source>
        <translation>ข้อความ</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>ความคิดเห็น</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>การทำรายการ</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>จำนวน</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>วันที่</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ชนิด</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ป้ายชื่อ</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation><numerusform>Open for %n more blocks</numerusform></translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีป้ายชื่อ)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>ทั้งหมด</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>วันนี้</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>สัปดาห์นี้</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>เดือนนี้</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>เดือนที่แล้ว</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>ปีนี้</translation>
    </message>
    <message>
        <source>A&amp;bandon transaction</source>
        <translation type="unfinished">&amp;Abandon transaction</translation>
    </message>
    <message>
        <source>Increase transaction &amp;fee</source>
        <translation type="unfinished">&amp;Increase transaction fee</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;คัดลอกที่อยู่</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;คัดลอกป้ายชื่อ</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;คัดลอกจำนวนเงิน</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;คัดลอก ID ธุรกรรม</translation>
    </message>
    <message>
        <source>Copy &amp;raw transaction</source>
        <translation type="unfinished">&amp;Copy raw transaction</translation>
    </message>
    <message>
        <source>Copy full transaction &amp;details</source>
        <translation type="unfinished">&amp;Copy full transaction details</translation>
    </message>
    <message>
        <source>&amp;Edit label</source>
        <translation type="unfinished">&amp;แก้ไขป้ายชื่อ</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ไฟล์ที่คั่นด้วยจุลภาค (* .csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>ยืนยันแล้ว</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>วันที่</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ชนิด</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ป้ายชื่อ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>ที่อยู่</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>การส่งออกล้มเหลว</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>ปิดกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>ปิดกระเป๋าสตางค์ทั้งหมด</translation>
    </message>
    <message>
        <source>Are you sure you wish to close all wallets?</source>
        <translation>คุณแน่ใจหรือไม่ว่าต้องการปิดกระเป๋าสตางค์ทั้งหมด?</translation>
    </message>
</context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>สร้างกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ข้อผิดพลาด</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>ส่งเหรียญ</translation>
    </message>
    <message>
        <source>PSBT copied</source>
        <translation>คัดลอก PSBT แล้ว</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>กระเป๋าสตางค์เริ่มต้น</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ส่งออก</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ส่งออกข้อมูลในแท็บปัจจุบันไปยังไฟล์</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>สำรองข้อมูลกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>ข้อมูลกระเป๋าสตางค์ (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>การสำรองข้อมูลล้มเหลว</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ยกเลิก</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>ข้อผิดพลาด</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>กำลังนำเข้า...</translation>
    </message>
    <message>
        <source>Unable to generate keys</source>
        <translation>ไม่สามารถสร้างกุญแจ</translation>
    </message>
    <message>
        <source>Upgrading UTXO database</source>
        <translation>กำลังอัปเกรดฐานข้อมูล UTXO</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>กำลังโหลดกระเป๋าสตางค์...</translation>
    </message>
    </context>
</TS>